@@ -245,11 +245,14 @@ class IntegrationTestCase(unittest.TestCase):
         self.assertEqual(published_url, uuidToURL(published_uuid))
         self.assertEqual(published_path, uuidToCatalogBrain(published_uuid).getPath())
         self.assertEqual(aq_base(published), aq_base(uuidToObject(published_uuid)))
+    
 
         # Currently, anonymous can also see the private item with most functions.
         # See the docstring of this test method.
         # But: when you get a brain with unrestrictedSearchResults,
         # the getObject may fail.
+        # Object can be accessed when unrestricted flag is set to True
+        self.assertEqual(aq_base(private), aq_base(uuidToObject(private_uuid, True)))
         self.assertEqual(private_path, uuidToPhysicalPath(private_uuid))
         self.assertEqual(private_url, uuidToURL(private_uuid))
         brain = uuidToCatalogBrain(private_uuid)
